@@ -11,7 +11,7 @@ import xarray as xr
 
 # ----------------------------------------------------------------------------------
 
-AXES = ["x", "y", "z1", "z2"]
+AXES = ["x", "y", "z", "t"]
 
 # ----------------------------------------------------------------------------------
 
